@@ -1,7 +1,7 @@
 #ifndef _PROCMAN_LOAD_GRAPH_H_
 #define _PROCMAN_LOAD_GRAPH_H_
 
-#include <glib/gtypes.h>
+#include <glib.h>
 #include <glibtop/cpu.h>
 
 enum
@@ -66,8 +66,7 @@ struct LoadGraph {
 	GtkWidget *main_widget;
 	GtkWidget *disp;
 
-	GdkGC *gc;
-	GdkDrawable *background;
+	cairo_surface_t *background;
 
 	guint timer_index;
 
@@ -88,7 +87,7 @@ struct LoadGraph {
 		struct {
 			guint64 last_in, last_out;
 			GTimeVal time;
-			unsigned int max;
+			guint64 max;
 			unsigned values[NUM_POINTS];
 			size_t cur;
 		} net;
@@ -99,7 +98,7 @@ struct LoadGraph {
 
 /* Force a drawing update */
 void
-load_graph_draw (LoadGraph *g);
+load_graph_queue_draw (LoadGraph *g);
 
 /* Start load graph. */
 void
