@@ -31,7 +31,7 @@
 #include "procactions.h"
 #include "util.h"
 #include "load-graph.h"
-#include "gconf-keys.h"
+#include "settings-keys.h"
 #include "procman_gnomesu.h"
 #include "procman_gksu.h"
 
@@ -159,7 +159,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
   	GtkWidget *label;
   	GtkWidget *priority_label;
   	GtkWidget *table;
-  	GtkObject *renice_adj;
+  	GtkAdjustment *renice_adj;
   	GtkWidget *hscale;
 	GtkWidget *button;
 	GtkWidget *align;
@@ -178,7 +178,6 @@ procdialog_create_renice_dialog (ProcData *procdata)
 				              NULL);
   	renice_dialog = dialog;
 	gtk_window_set_resizable (GTK_WINDOW (renice_dialog), FALSE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (renice_dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (renice_dialog), 5);
   	
 	button = gtk_button_new ();
@@ -220,7 +219,7 @@ procdialog_create_renice_dialog (ProcData *procdata)
 	
 	renice_adj = gtk_adjustment_new (info->nice, RENICE_VAL_MIN, RENICE_VAL_MAX, 1, 1, 0);
 	new_nice_value = 0;
-	hscale = gtk_hscale_new (GTK_ADJUSTMENT (renice_adj));
+	hscale = gtk_hscale_new (renice_adj);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), hscale);
 	gtk_scale_set_digits (GTK_SCALE (hscale), 0);
 	gtk_table_attach (GTK_TABLE (table), hscale, 1, 2, 0, 1,
@@ -262,14 +261,13 @@ static void
 show_kill_dialog_toggled (GtkToggleButton *button, gpointer data)
 {
 	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
-	
+	GSettings *settings = procdata->settings;
+
 	gboolean toggled;
 	
 	toggled = gtk_toggle_button_get_active (button);
 	
-	gconf_client_set_bool (client, "/apps/procman/kill_dialog", toggled, NULL);
-		
+	g_settings_set_boolean (settings, "kill-dialog", toggled);
 }
 
 
@@ -278,10 +276,11 @@ static void
 solaris_mode_toggled(GtkToggleButton *button, gpointer data)
 {
 	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
+	GSettings *settings = procdata->settings;
+
 	gboolean toggled;
 	toggled = gtk_toggle_button_get_active(button);
-	gconf_client_set_bool(client, procman::gconf::solaris_mode.c_str(), toggled, NULL);
+	g_settings_set_boolean(settings, procman::settings::solaris_mode.c_str(), toggled);
 }
 
 
@@ -289,10 +288,11 @@ static void
 network_in_bits_toggled(GtkToggleButton *button, gpointer data)
 {
 	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
+	GSettings *settings = procdata->settings;
+
 	gboolean toggled;
 	toggled = gtk_toggle_button_get_active(button);
-	gconf_client_set_bool(client, procman::gconf::network_in_bits.c_str(), toggled, NULL);
+	g_settings_set_boolean(settings, procman::settings::network_in_bits.c_str(), toggled);
 }
 
 
@@ -301,13 +301,13 @@ static void
 smooth_refresh_toggled(GtkToggleButton *button, gpointer data)
 {
 	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
-
+	GSettings *settings = procdata->settings;
+	
 	gboolean toggled;
 
 	toggled = gtk_toggle_button_get_active(button);
 
-	gconf_client_set_bool(client, SmoothRefresh::KEY.c_str(), toggled, NULL);
+	g_settings_set_boolean(settings, SmoothRefresh::KEY.c_str(), toggled);
 }
 
 
@@ -316,21 +316,21 @@ static void
 show_all_fs_toggled (GtkToggleButton *button, gpointer data)
 {
 	ProcData *procdata = static_cast<ProcData*>(data);
-	GConfClient *client = procdata->client;
-
+	GSettings *settings = procdata->settings;
+	
 	gboolean toggled;
 
 	toggled = gtk_toggle_button_get_active (button);
 
-	gconf_client_set_bool (client, "/apps/procman/show_all_fs", toggled, NULL);
+	g_settings_set_boolean (settings, "show-all-fs", toggled);
 }
 
 
 class SpinButtonUpdater
 {
 public:
-  SpinButtonUpdater(const string& gconf_key)
-    : gconf_key(gconf_key)
+  SpinButtonUpdater(const string& key)
+    : key(key)
   { }
 
   static gboolean callback(GtkWidget *widget, GdkEventFocus *event, gpointer data)
@@ -345,20 +345,14 @@ private:
   void update(GtkSpinButton* spin)
   {
     int new_value = int(1000 * gtk_spin_button_get_value(spin));
-    GError* e = 0;
 
-    if (not gconf_client_set_int(ProcData::get_instance()->client,
-				 this->gconf_key.c_str(), new_value,
-				 &e)) {
-      g_warning("Failed to gconf_client_set_int %s %d : %s\n",
-		this->gconf_key.c_str(), new_value, e->message);
-      g_error_free(e);
-    }
+    g_settings_set_int(ProcData::get_instance()->settings,
+                       this->key.c_str(), new_value);
 
-    procman_debug("set %s to %d", this->gconf_key.c_str(), new_value);
+    procman_debug("set %s to %d", this->key.c_str(), new_value);
   }
 
-  const string gconf_key;
+  const string key;
 };
 
 
@@ -474,9 +468,9 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
 	typedef SpinButtonUpdater SBU;
 
-	static SBU interval_updater("/apps/procman/update_interval");
-	static SBU graph_interval_updater("/apps/procman/graph_update_interval");
-	static SBU disks_interval_updater("/apps/procman/disks_interval");
+	static SBU interval_updater("update-interval");
+	static SBU graph_interval_updater("graph-update-interval");
+	static SBU disks_interval_updater("disks-interval");
 
 	GtkWidget *notebook;
 	GtkWidget *proc_box;
@@ -510,7 +504,6 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	/* any function to set list height by contents/items inside it. */
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 400, 420);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	prefs_dialog = dialog;
 	
 	main_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
@@ -561,7 +554,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 							  MAX_UPDATE_INTERVAL / 1000,
 							  0.25,
 							  1.0,
-							  1.0);
+							  0);
 
 	spin_button = gtk_spin_button_new (adjustment, 1.0, 2);
 	gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
@@ -575,9 +568,8 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 
 	smooth_button = gtk_check_button_new_with_mnemonic(_("Enable _smooth refresh"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(smooth_button),
-				     gconf_client_get_bool(procdata->client,
-							   SmoothRefresh::KEY.c_str(),
-							   NULL));
+				     g_settings_get_boolean(procdata->settings,
+							   SmoothRefresh::KEY.c_str()));
 	g_signal_connect(G_OBJECT(smooth_button), "toggled",
 			 G_CALLBACK(smooth_refresh_toggled), procdata);
 	gtk_box_pack_start(GTK_BOX(hbox2), smooth_button, TRUE, TRUE, 0);
@@ -592,20 +584,19 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 				      procdata->config.show_kill_warning);
 	g_signal_connect (G_OBJECT (check_button), "toggled",
 			    G_CALLBACK (show_kill_dialog_toggled), procdata);
-	gtk_box_pack_start (GTK_BOX (hbox2), check_button, FALSE, FALSE, 0);
-	
+	gtk_box_pack_start (GTK_BOX (hbox2), check_button, TRUE, TRUE, 0);
+
 
 
 
 	hbox2 = gtk_hbox_new(FALSE, 6);
 	gtk_box_pack_start(GTK_BOX(vbox2), hbox2, FALSE, FALSE, 0);
 
-	GtkWidget *solaris_button;
-	solaris_button = gtk_check_button_new_with_mnemonic(_("Solaris mode"));
+	GtkWidget *solaris_button = gtk_check_button_new_with_mnemonic(_("Divide CPU usage by CPU count"));
+	gtk_widget_set_tooltip_text(solaris_button, _("Solaris mode"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(solaris_button),
-				     gconf_client_get_bool(procdata->client,
-							   procman::gconf::solaris_mode.c_str(),
-							   NULL));
+				     g_settings_get_boolean(procdata->settings,
+							   procman::settings::solaris_mode.c_str()));
 	g_signal_connect(G_OBJECT(solaris_button), "toggled",
 			 G_CALLBACK(solaris_mode_toggled), procdata);
 	gtk_box_pack_start(GTK_BOX(hbox2), solaris_button, TRUE, TRUE, 0);
@@ -673,7 +664,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 			  
 	update = (gfloat) procdata->config.graph_update_interval;
 	adjustment = (GtkAdjustment *) gtk_adjustment_new(update / 1000.0, 0.25, 
-							  100.0, 0.25, 1.0, 1.0);
+							  100.0, 0.25, 1.0, 0);
 	spin_button = gtk_spin_button_new (adjustment, 1.0, 2);
 	g_signal_connect (G_OBJECT (spin_button), "focus_out_event",
 			  G_CALLBACK(SBU::callback),
@@ -685,9 +676,8 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	GtkWidget *bits_button;
 	bits_button = gtk_check_button_new_with_mnemonic(_("Show network speed in bits"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(bits_button),
-				     gconf_client_get_bool(procdata->client,
-							   procman::gconf::network_in_bits.c_str(),
-							   NULL));
+				     g_settings_get_boolean(procdata->settings,
+							   procman::settings::network_in_bits.c_str()));
 	g_signal_connect(G_OBJECT(bits_button), "toggled",
 			 G_CALLBACK(network_in_bits_toggled), procdata);
 	gtk_box_pack_start(GTK_BOX(vbox2), bits_button, TRUE, TRUE, 0);
@@ -734,7 +724,7 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 			  
 	update = (gfloat) procdata->config.disks_update_interval;
 	adjustment = (GtkAdjustment *) gtk_adjustment_new (update / 1000.0, 1.0, 
-							   100.0, 1.0, 1.0, 1.0);
+							   100.0, 1.0, 1.0, 0);
 	spin_button = gtk_spin_button_new (adjustment, 1.0, 0);
 	gtk_box_pack_start (GTK_BOX (hbox3), spin_button, FALSE, FALSE, 0);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spin_button);
